/**
 * @version 1.0.0
 * @description GITTE类型
 * @example import { GITEE_TYPE } from 'gitee-code-web-sdk';
 */
import { type Feature_Toggles } from './feature_toggles';
import { type Project } from './project';
import { I18nName } from './enum';
import { Axios } from 'axios';
type AnyKeyType = {
    [key: string]: string | number | boolean | object | null;
};
interface UserInfo {
    enterprise_uuid: string;
    enterpriseUuidPath: string;
    program_uuid: string;
}
interface EnterpriseInfo {
    name: string;
    path: string;
    project_name_regular: string;
}
interface CurrentUser extends AnyKeyType {
    info: UserInfo;
    FEATURE_TOGGLES: Feature_Toggles;
    feature_toggles: Feature_Toggles;
    feature_toggles_value: {
        jira_type: string;
    };
    enterprise: EnterpriseInfo;
    project: Project;
    user: {
        username: string;
        can_manage_enterprise: boolean;
        can_visit_enterprise: boolean;
    } & AnyKeyType;
}
export type GITEE_TYPE = {
    /**
     * @description 当前用户信息
     */
    currentUser: CurrentUser;
    openDialog: string | number | boolean | object | null | Function;
    /**
     * @description 更新schema
     * @param data 更新的schema
     */
    updateSchema: (data: any) => void;
    /**
     * @description 注册EventHub监听事件
     * @param eventName 事件名称
     * @param handler 事件处理函数
     * @param opts 配置项
     */
    on: (eventName: string, handler: (...args: any[]) => void, opts?: {
        once: boolean;
    }) => void;
    /**
     * 合并国际化信息
     * @param key - 国际化键名 zh-CN|en-US|ru-RU|zh-TW
     * @param arg - 对象，包含要合并的数据
     */
    mergeI18n: (key: I18nName, arg: object) => void;
    /**
     * @description 国际化
     * @returns string - 国际化文本
     */
    $t: (...args: any[]) => string;
    /**
     * @description 拼接国际化
     * @returns string - 拼接后的国际化文本
     */
    $t_join: (key: string, ...args: any[]) => string;
    /**
     * @description MessageBox.confirm确认框
     */
    $confirm: (...args: any[]) => Promise<any>;
    /**
     * @description axios 请求
     */
    $http: Axios;
    api: {
        /**
         * @description 接口前缀及注册全局api
         * @param module 模块名称
         * @param name api方法名称
         * @param api axios请求
         * @demo register('projects', 'getRepoGroups', $http.get(`${goComApiPrefix()}/projects/transport_groups`, { params }))
         */
        register: (module: string, name: string, api: (...args: any[]) => Axios) => void;
        /**
         * @description 企业设置api前缀
         */
        goComApiPrefix: () => string;
        /**
         * 仓库组api前缀
         */
        goGroupFullPathPrefix: (path?: string) => string;
        /**
         * 仓库api前缀
         */
        goApiProjectPrefix: (path?: string) => string;
        API_GO_BASEURL: string;
    };
    /**
     * @description 代码库详情
     */
    project: Project;
    /**
     * @description 注册事件
     * @param eventName 事件名称
     * @param handler 事件处理函数
     */
    REGISTER_EVENT: (eventName: string, handler: (...args: any[]) => void) => void;
    /**
     * @description 判断是否是仓库组页面
     */
    isRepoGroupPage: Boolean;
    /**
     * @description 判断是否是仓库页面
     */
    inProjectPage: Boolean;
    /**
     * @description 全局功能开关
     */
    FEATURE_TOGGLES: Feature_Toggles;
    FEATURE_TOGGLES_VALUE: {
        jira_type: string;
    };
    /**
     * @description vuex store 对象,
     */
    STORE: any;
    /**
     * @description vue-roluer 路由对象
     */
    $route: any;
    /**
     * @description 设置全局Loading
     * @param loading 是否显示loading
     */
    SET_GLOBAL_LOADING: (loading: boolean) => void;
    /**
     * @description 注册vuex模块
     * @param name 模块名称
     * @param module 模块内容容括state、mutations、actions、getters
     */
    registerVuexModule: (name: string, module: object) => void;
    /**
     * @description 自定义switch开关组件
     */
    FormItemSwitch: HTMLElement;
};
export {};
